/******************************************************************************

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

#ifndef EXCEPTIONS_H
#define EXCEPTIONS_H

#include <string>
#include <exception>

/**
 * A boring exception list.
 */
class AntispellException : public std::exception {
public:
     AntispellException(const std::string& whatString) {
	  p = whatString.c_str();
     }
     virtual const char* what() const throw() {
	  return p;
     }
private:
     const char* p;
};

class NotFoundException : public AntispellException {
public:
     NotFoundException(const std::string& whatString) 
	  : AntispellException(whatString) { }
};
class StrangeLetterException : public AntispellException {
public:
     StrangeLetterException(const std::string& whatString="StrangeLetterException") 
	  : AntispellException(whatString) { }
};
class TagNotFoundException : public AntispellException {
public:
     TagNotFoundException(const std::string& whatString="TagNotFoundException") 
	  : AntispellException(whatString) { }
};
class NotCharException : public AntispellException {
public:
     NotCharException(const std::string& whatString="NotCharException") 
	  : AntispellException(whatString) { }
};
class NotBooleanValueException : public AntispellException {
public:
     NotBooleanValueException(const std::string& whatString="NotBooleanValueException") 
	  : AntispellException(whatString) { }
};
class ParamNotFoundException : public AntispellException {
public:
     ParamNotFoundException(const std::string& whatString="ParamNotFoundException") 
	  : AntispellException(whatString) { }
};
class InputParseException : public AntispellException {
public:
     InputParseException(const std::string& whatString="InputParseException") 
	  : AntispellException(whatString) { }
};
class EndOfInputException : public AntispellException {
public:
     EndOfInputException(const std::string& whatString="EndOfInputException") 
	  : AntispellException(whatString) { }
};
class ConfusionMatrixException : public AntispellException {
public:
     ConfusionMatrixException(const std::string& whatString="ConfusionMatrixException") 
	  : AntispellException(whatString) { }
};
class OperationNotPermitted : public AntispellException {
public:
     OperationNotPermitted(const std::string& whatString="OperationNotPermitted")
	  : AntispellException(whatString) { }
};

#endif
