/******************************************************************************

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

#include "introducerlist.hpp"

IntroducerList::IntroducerList(Wordlist &wl, Settings &se, ErrorWriter &ew, InputReader &ir)
     : wordlist(wl)
     , settings(se)
     , errorwriter(ew) 
     , inputreader(ir) {
     readAllFiles();
}

void IntroducerList::readAllFiles() {
     std::list<std::string> params;
     params.push_back("active");
     params.push_back("filename");
     params.push_back("probability");
     std::string configDir = settings.getString("options/configDir", "");
     try {
	  Settings::SubParameters ret = settings.allSubParameters("errorIntroducer/modules/module", params);
	  for (Settings::SubParameters::const_iterator iter = ret.begin(); iter != ret.end(); ++iter) {
	       std::list<std::string>::const_iterator param_iter = iter->begin();
	       if (Settings::toBool(*param_iter, false)) {
		    //std::cerr << "ACTIVE\n";
		    ++param_iter;
		    std::string filename = configDir + *param_iter;
		    //std::cerr << filename << std::endl;
		    ++param_iter;
		    double probability = Settings::toDouble(*param_iter, 30.0);
		    ErrorIntroducer errorintroducer(wordlist, settings, errorwriter, inputreader, filename);
		    introducerlist.push_back(std::make_pair(errorintroducer, probability));
	       }
	  }
     }
     catch (const NotFoundException &e) {
	  std::cerr << "Error: " << e.what() << std::endl;
     }
     catch (...) {
	  std::cerr << "Unexpected exception.\n";
     }
}

std::list<std::pair<ErrorIntroducer,double> >& IntroducerList::getList() {
     return introducerlist;
}

