/******************************************************************************

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <iostream>
#include <string>
#include <set>
#include <list>

#include <xercesc/parsers/XercesDOMParser.hpp>
#include <xercesc/dom/DOM.hpp>
#include <xercesc/dom/DOMNode.hpp>
#include <xercesc/sax/HandlerBase.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/util/PlatformUtils.hpp>

#include <boost/tokenizer.hpp>
#include <boost/lexical_cast.hpp>
#include <boost/regex.hpp>

#include "exceptions.hpp"
#include "utils.hpp"
#include "myerrorhandler.hpp"

XERCES_CPP_NAMESPACE_USE

/**
 * An abstract settings class.
 * All needed functions except allParameters and parameterValue are defined.
 */
class Settings {
protected:
    Settings(const std::string&);
public:
    typedef boost::char_separator<char> Separator;
    typedef boost::tokenizer<Separator> Tokenizer;
    typedef std::set<std::list<std::string> > SubParameters;
     
    virtual ~Settings();

    virtual std::set<std::string> allParameters(const std::string&, const std::string&) const = 0;
    virtual SubParameters allSubParameters(const std::string&, const std::list<std::string>&) const;

    /* Read a value from the settings at the position defined by the
     * string value. If the setting is not found the default value is used.
     */
    int getInt(const std::string&, int) const;
    std::string getString(const std::string&, const std::string&) const;     
    bool getBool(const std::string&, bool) const;
    char getChar(const std::string&, char) const;
    double getDouble(const std::string&, double) const;

    static int toInt(const std::string&, int);
    static bool toBool(const std::string&, bool);
    static char toChar(const std::string&, char);
    static double toDouble(const std::string&, double);
protected:
    virtual std::string parameterValue(const std::string&) const throw(ParamNotFoundException) = 0;
    XercesDOMParser* parser;
    ErrorHandler* errHandler;
};

#endif
